/* 
 * Purpose: Run and plot nonparametric regression of t&d losses on access to electricity (Figure 3)
 * Data source: World Bank portal, accessed in 2018
 */


pause on
set more off
set varabbrev off
set matsize 10000
cap log close
clear

*** file paths

if "`c(os)'" == "MacOSX" {
*	global ROOT ""
	cd "$ROOT/Code"
	local DATA "$ROOT/Data"
	local OUTPUT "$ROOT"
}

*** graph fonts
set scheme s2mono
graph set window fontface "Times New Roman"


***

	use "`DATA'/wb_panel.dta", clear

	label var td "T&D Losses (%)"
	label var ac "Access to Electricity (%)"
	
	* for td vs ac, keep only observations with both nonmissing
	keep if !missing(td) & !missing(ac)
	
	* count number of countries (all and with nonmissing in all years)
	**** reported in paper
	distinct country // report as number of countries
	bysort country: gen numyrs = _N
	tab numyrs
	distinct country if numyrs == 25 // report as number of countries with all 25 years of data
	
	******** GRAPH TO KEEP: LOCAL LINEAR FIT WITH HISTOGRAM OVERLAYED
	graph twoway hist ac [fw = pop], yaxis(2) width(5) frac ytitle("Fraction of Population", axis(2)) ///
		legend(label(1 "Share of Population")) || ///
		lpolyci td ac [aw = pop], degree(1) yaxis(1) ysc(range(0 35)) ylab(0(5)35) yscale(alt) yscale(alt axis(2)) ///
		ytitle("T&D Losses (%)") legend(label(2 "95% Confidence Interval") label(3 "Predicted T&D Losses From Local Linear Regression")) || ///
		, graphregion(color(white)) plotregion(color(white)) bgcolor(white) title("") xtitle("Access to Electricity (%)") ///
		legend(order(3 2 1) cols(1) region(lcolor(white)))
	
	graph export "`OUTPUT'/np_graph_td_ac_with_hist.pdf", replace
	







